@@ -1,19 +1,19 @@
-/** 
+/*
  * XML Security Library (http://www.aleksey.com/xmlsec).
  *
  * All the string constans.
  *
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
- * 
- * Copyright (C) 2002-2003 Aleksey Sanin <aleksey@aleksey.com>
+ *
+ * Copyright (C) 2002-2016 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
 #ifndef __XMLSEC_STRINGS_H__
-#define __XMLSEC_STRINGS_H__    
+#define __XMLSEC_STRINGS_H__
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
 #include <libxml/tree.h>
 
@@ -27,7 +27,6 @@ extern "C" {
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNs[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecDSigNs[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecEncNs[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsNs[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecXPathNs[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecXPath2Ns[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecXPointerNs[];
@@ -71,127 +70,6 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeCarriedKeyName[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecTypeEncContent[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecTypeEncElement[];
 
-/*************************************************************************
- *
- * XKMS nodes, attributes  and value strings
- *
- ************************************************************************/
-#ifndef XMLSEC_NO_XKMS
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestResultName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestStatusName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestLocateName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestValidateName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsServerRequestCompoundName[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeResult[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeStatusRequest[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeStatusResult[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeLocateRequest[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeLocateResult[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidateRequest[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidateResult[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeCompoundRequest[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeCompoundResult[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeMessageExtension[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeOpaqueClientData[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeResponseMechanism[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRespondWith[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodePendingNotification[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeQueryKeyBinding[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeKeyUsage[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeUseKeyWith[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeTimeInstant[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRequestSignatureValue[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeUnverifiedKeyBinding[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidityInterval[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeStatus[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeValidReason[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeInvalidReason[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeIndeterminateReason[];
-
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrService[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrNonce[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrOriginalRequestId[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrResponseLimit[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrMechanism[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrIdentifier[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrApplication[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrResultMajor[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrResultMinor[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrRequestId[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrNotBefore[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrNotOnOrAfter[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrTime[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecAttrStatusValue[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseMechanismPending[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseMechanismRepresent[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResponseMechanismRequestSignatureValue[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithKeyName[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithKeyValue[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithX509Cert[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithX509Chain[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithX509CRL[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithOCSP[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithRetrievalMethod[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithPGP[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithPGPWeb[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithSPKI[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecRespondWithPrivateKey[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecStatusResultSuccess[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecStatusResultFailed[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecStatusResultPending[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyUsageEncryption[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyUsageSignature[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyUsageExchange[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingStatusValid[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingStatusInvalid[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingStatusIndeterminate[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonIssuerTrust[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonRevocationStatus[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonValidityInterval[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecKeyBindingReasonSignature[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeSuccess[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeVersionMismatch[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeSender[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeReceiver[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodeRepresent[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMajorCodePending[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeNoMatch[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeTooManyResponses[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeIncomplete[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeFailure[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeRefused[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeNoAuthentication[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeMessageNotSupported[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeUnknownResponseId[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecResultMinorCodeNotSynchronous[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonLang[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonUnsupportedVersion[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonUnableToProcess[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonServiceUnavailable[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonMessageNotSupported[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapFaultReasonMessageInvalid[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapSubcodeValueMessageNotSupported[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsSoapSubcodeValueBadMessage[];
-
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsFormatStrPlain[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsFormatStrSoap11[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecXkmsFormatStrSoap12[];
-
-#endif /* XMLSEC_NO_XKMS */
-
 /*************************************************************************
  *
  * KeyInfo and Transform Nodes
@@ -235,6 +113,15 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes192Cbc[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameAes256Cbc[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes256Cbc[];
 
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameAes128Gcm[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes128Gcm[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameAes192Gcm[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes192Gcm[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameAes256Gcm[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefAes256Gcm[];
+
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameKWAes128[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefKWAes128[];
 
@@ -263,6 +150,12 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefC14N[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameC14NWithComments[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefC14NWithComments[];
 
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameC14N11[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefC14N11[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameC14N11WithComments[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefC14N11WithComments[];
+
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameExcC14N[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefExcC14N[];
 
@@ -312,6 +205,75 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeDSAPgenCounter[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameDsaSha1[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDsaSha1[];
 
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameDsaSha256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefDsaSha256[];
+
+/*************************************************************************
+ *
+ * ECDSA strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameECDSAKeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECDSAKeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefECDSAKeyValue[];
+
+/* XXX-MAK: More constants will be needed later. */
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECDSAP[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECDSAQ[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECDSAG[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECDSAJ[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECDSAX[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECDSAY[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECDSASeed[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeECDSAPgenCounter[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha1[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha1[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha224[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha384[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameEcdsaSha512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefEcdsaSha512[];
+
+/*************************************************************************
+ *
+ * GOST2001 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGOST2001KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeGOST2001KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGOST2001KeyValue[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGost2001GostR3411_94[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGost2001GostR3411_94[];
+
+/*************************************************************************
+ *
+ * GOST R 34.10-2012 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3410_2012_256KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeGostR3410_2012_256KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3410_2012_256KeyValue[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3410_2012_512KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeGostR3410_2012_512KeyValue[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3410_2012_512KeyValue[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3410_2012GostR3411_2012_256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3410_2012GostR3411_2012_256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3410_2012GostR3411_2012_512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3410_2012GostR3411_2012_512[];
+
+
 /*************************************************************************
  *
  * EncryptedKey
@@ -340,14 +302,26 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHMACKeyValue[];
 
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeHMACOutputLength[];
 
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacSha1[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacSha1[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacMd5[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacMd5[];
 
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacRipemd160[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacRipemd160[];
 
-XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacMd5[];
-XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacMd5[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacSha1[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacSha1[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacSha224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacSha224[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacSha256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacSha256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacSha384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacSha384[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameHmacSha512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefHmacSha512[];
 
 /*************************************************************************
  *
@@ -372,6 +346,14 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeKeyValue[];
  ************************************************************************/
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameMemBuf[];
 
+/*************************************************************************
+ *
+ * MD5 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameMd5[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefMd5[];
+
 /*************************************************************************
  *
  * RetrievalMethod
@@ -401,9 +383,27 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRSAModulus[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRSAExponent[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRSAPrivateExponent[];
 
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaMd5[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaMd5[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaRipemd160[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaRipemd160[];
+
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaSha1[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaSha1[];
 
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaSha224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaSha224[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaSha256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaSha256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaSha384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaSha384[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaSha512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaSha512[];
+
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaPkcs1[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaPkcs1[];
 
@@ -411,6 +411,24 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRsaOaep[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRsaOaep[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRsaOAEPparams[];
 
+/*************************************************************************
+ *
+ * GOSTR3411_94 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3411_94[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3411_94[];
+
+/*************************************************************************
+ *
+ * GOST R 34.11-2012 strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3411_2012_256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3411_2012_256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameGostR3411_2012_512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefGostR3411_2012_512[];
+
 /*************************************************************************
  *
  * SHA1 strings
@@ -419,6 +437,18 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRsaOAEPparams[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha1[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha1[];
 
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha224[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha224[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha256[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha256[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha384[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha384[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameSha512[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefSha512[];
+
 /*************************************************************************
  *
  * X509 strings
@@ -475,6 +505,22 @@ XMLSEC_EXPORT_VAR const xmlChar xmlSecXPath2FilterUnion[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNameXPointer[];
 XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeXPointer[];
 
+/*************************************************************************
+ *
+ * RelationshipTransform strings
+ *
+ ************************************************************************/
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNameRelationship[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecHrefRelationship[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRelationship[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecNodeRelationshipReference[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipsNs[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipReferenceNs[];
+
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipAttrId[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipAttrSourceId[];
+XMLSEC_EXPORT_VAR const xmlChar xmlSecRelationshipAttrTargetMode[];
+
 /*************************************************************************
  *
  * Xslt strings
