@@ -246,7 +246,7 @@ xmlSecCryptoDLLibraryConstructFilename(const xmlChar* name) {
     xmlSecAssert2(name != NULL, NULL);
 
     /* TODO */
-    len = xmlStrlen(BAD_CAST PACKAGE) + xmlStrlen(name) + strlen(tmpl) + 1;
+    len = xmlStrlen(BAD_CAST PACKAGE) + xmlStrlen(name) + xmlStrlen(BAD_CAST tmpl) + 1;
     res = (xmlChar*)xmlMalloc(len + 1);
     if(res == NULL) {
         xmlSecMallocError(len + 1, NULL);
@@ -272,7 +272,7 @@ xmlSecCryptoDLLibraryConstructGetFunctionsName(const xmlChar* name) {
 
     xmlSecAssert2(name != NULL, NULL);
 
-    len = xmlStrlen(name) + strlen(tmpl) + 1;
+    len = xmlStrlen(name) + xmlStrlen(BAD_CAST tmpl) + 1;
     res = (xmlChar*)xmlMalloc(len + 1);
     if(res == NULL) {
         xmlSecMallocError(len + 1, NULL);
@@ -371,6 +371,8 @@ xmlSecCryptoDLShutdown(void) {
     if(ret != 0) {
         xmlSecIOError("lt_dlexit", NULL, NULL);
     }
+#else  /* XMLSEC_DL_LIBLTDL */
+    UNREFERENCED_PARAMETER(ret);
 #endif /* XMLSEC_DL_LIBLTDL */
 
     return(0);
@@ -619,6 +621,24 @@ xmlSecCryptoDLFunctionsRegisterKeyDataAndTransforms(struct _xmlSecCryptoDLFuncti
         return(-1);
     }
 
+    if ((functions->transformAes128GcmGetKlass != NULL) && xmlSecTransformIdsRegister(functions->transformAes128GcmGetKlass()) < 0) {
+        xmlSecInternalError("xmlSecTransformIdsRegister",
+                            xmlSecTransformKlassGetName(functions->transformAes128GcmGetKlass()));
+        return(-1);
+    }
+
+    if ((functions->transformAes192GcmGetKlass != NULL) && xmlSecTransformIdsRegister(functions->transformAes192GcmGetKlass()) < 0) {
+        xmlSecInternalError("xmlSecTransformIdsRegister",
+                            xmlSecTransformKlassGetName(functions->transformAes192GcmGetKlass()));
+        return(-1);
+    }
+
+    if ((functions->transformAes256GcmGetKlass != NULL) && xmlSecTransformIdsRegister(functions->transformAes256GcmGetKlass()) < 0) {
+        xmlSecInternalError("xmlSecTransformIdsRegister",
+                            xmlSecTransformKlassGetName(functions->transformAes256GcmGetKlass()));
+        return(-1);
+    }
+
     if((functions->transformKWAes128GetKlass != NULL) && xmlSecTransformIdsRegister(functions->transformKWAes128GetKlass()) < 0) {
         xmlSecInternalError("xmlSecTransformIdsRegister",
                             xmlSecTransformKlassGetName(functions->transformKWAes128GetKlass()));
