@@ -1,14 +1,19 @@
-/**
- * XMLSec library
- *
- * X509 support
+/*
+ * XML Security Library (http://www.aleksey.com/xmlsec).
  *
  *
  * This is free software; see Copyright file in the source
  * distribution for preciese wording.
  *
- * Copyright (C) 2010 Aleksey Sanin <aleksey@aleksey.com>
+ * Copyright (C) 2010-2016 Aleksey Sanin <aleksey@aleksey.com>. All Rights Reserved.
  */
+/**
+ * SECTION:x509vfy
+ * @Short_description: X509 certificates verification support functions for GnuTLS.
+ * @Stability: Private
+ *
+ */
+
 #include "globals.h"
 
 #ifndef XMLSEC_NO_X509
@@ -159,38 +164,28 @@ xmlSecGnuTLSX509CheckTime(const gnutls_x509_crt_t * cert_list,
         /* get expiration times */
         notValidBefore = gnutls_x509_crt_get_activation_time(cert);
         if(notValidBefore == (time_t)-1) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "gnutls_x509_crt_get_activation_time",
-                        XMLSEC_ERRORS_R_CRYPTO_FAILED,
-                        XMLSEC_ERRORS_NO_MESSAGE);
+            xmlSecGnuTLSError2("gnutls_x509_crt_get_activation_time", GNUTLS_E_SUCCESS,
+                               NULL,
+                               "cert activation time is invalid: %ld",
+                               (unsigned long)notValidBefore);
             return(-1);
         }
         notValidAfter = gnutls_x509_crt_get_expiration_time(cert);
         if(notValidAfter == (time_t)-1) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "gnutls_x509_crt_get_expiration_time",
-                        XMLSEC_ERRORS_R_CRYPTO_FAILED,
-                        XMLSEC_ERRORS_NO_MESSAGE);
+            xmlSecGnuTLSError2("gnutls_x509_crt_get_expiration_time", GNUTLS_E_SUCCESS,
+                               NULL,
+                               "cert expiration time is invalid: %ld",
+                               (unsigned long)notValidAfter);
             return(-1);
        }
 
         /* check */
         if(ts < notValidBefore) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        NULL,
-                        XMLSEC_ERRORS_R_CERT_NOT_YET_VALID,
-                        XMLSEC_ERRORS_NO_MESSAGE);
+            xmlSecOtherError(XMLSEC_ERRORS_R_CERT_NOT_YET_VALID, NULL, NULL);
             return(0);
         }
         if(ts > notValidAfter) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        NULL,
-                        XMLSEC_ERRORS_R_CERT_HAS_EXPIRED,
-                        XMLSEC_ERRORS_NO_MESSAGE);
+            xmlSecOtherError(XMLSEC_ERRORS_R_CERT_HAS_EXPIRED, NULL, NULL);
             return(0);
         }
     }
@@ -249,11 +244,8 @@ xmlSecGnuTLSX509StoreVerify(xmlSecKeyDataStorePtr store,
     if(cert_list_length > 0) {
         cert_list = (gnutls_x509_crt_t *)xmlMalloc(sizeof(gnutls_x509_crt_t) * cert_list_length);
         if(cert_list == NULL) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                        "xmlMalloc",
-                        XMLSEC_ERRORS_R_MALLOC_FAILED,
-                        "size=%d", (int)(sizeof(gnutls_x509_crt_t) * cert_list_length));
+            xmlSecMallocError(sizeof(gnutls_x509_crt_t) * cert_list_length,
+                              xmlSecKeyDataStoreGetName(store));
             goto done;
         }
     }
@@ -261,21 +253,15 @@ xmlSecGnuTLSX509StoreVerify(xmlSecKeyDataStorePtr store,
     if(crl_list_length > 0) {
         crl_list = (gnutls_x509_crl_t *)xmlMalloc(sizeof(gnutls_x509_crl_t) * crl_list_length);
         if(crl_list == NULL) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                        "xmlMalloc",
-                        XMLSEC_ERRORS_R_MALLOC_FAILED,
-                        "size=%d", (int)(sizeof(gnutls_x509_crl_t) * crl_list_length));
+            xmlSecMallocError(sizeof(gnutls_x509_crl_t) * crl_list_length,
+                              xmlSecKeyDataStoreGetName(store));
             goto done;
         }
         for(ii = 0; ii < crl_list_length; ++ii) {
             crl_list[ii] = xmlSecPtrListGetItem(crls, ii);
             if(crl_list[ii] == NULL) {
-                xmlSecError(XMLSEC_ERRORS_HERE,
-                            xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                            "xmlSecPtrListGetItem(crls)",
-                            XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                            XMLSEC_ERRORS_NO_MESSAGE);
+                xmlSecInternalError("xmlSecPtrListGetItem(crls)",
+                                    xmlSecKeyDataStoreGetName(store));
                 goto done;
             }
         }
@@ -285,21 +271,15 @@ xmlSecGnuTLSX509StoreVerify(xmlSecKeyDataStorePtr store,
     if(ca_list_length > 0) {
         ca_list = (gnutls_x509_crt_t *)xmlMalloc(sizeof(gnutls_x509_crt_t) * ca_list_length);
         if(ca_list == NULL) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                        "xmlMalloc",
-                        XMLSEC_ERRORS_R_MALLOC_FAILED,
-                        "size=%d", (int)(sizeof(gnutls_x509_crt_t) * ca_list_length));
+            xmlSecMallocError(sizeof(gnutls_x509_crt_t) * ca_list_length,
+                              xmlSecKeyDataStoreGetName(store));
             goto done;
         }
         for(ii = 0; ii < ca_list_length; ++ii) {
             ca_list[ii] = xmlSecPtrListGetItem(&(ctx->certsTrusted), ii);
             if(ca_list[ii] == NULL) {
-                xmlSecError(XMLSEC_ERRORS_HERE,
-                            xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                            "xmlSecPtrListGetItem(certsTrusted)",
-                            XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                            XMLSEC_ERRORS_NO_MESSAGE);
+                xmlSecInternalError("xmlSecPtrListGetItem(certsTrusted)",
+                                    xmlSecKeyDataStoreGetName(store));
                 goto done;
             }
         }
@@ -325,11 +305,8 @@ xmlSecGnuTLSX509StoreVerify(xmlSecKeyDataStorePtr store,
 
         cert = xmlSecPtrListGetItem(certs, ii);
         if(cert == NULL) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                        "xmlSecPtrListGetItem(certs)",
-                        XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                        XMLSEC_ERRORS_NO_MESSAGE);
+            xmlSecInternalError("xmlSecPtrListGetItem(certs)",
+                                xmlSecKeyDataStoreGetName(store));
             goto done;
         }
 
@@ -357,26 +334,24 @@ xmlSecGnuTLSX509StoreVerify(xmlSecKeyDataStorePtr store,
         }
 
         /* try to verify */
-        err = gnutls_x509_crt_list_verify(
-                cert_list, (int)cert_list_cur_length, /* certs chain */
-                ca_list, (int)ca_list_length, /* trusted cas */
-                crl_list, (int)crl_list_length, /* crls */
-                flags, /* flags */
-                &verify);
+	if((keyInfoCtx->flags & XMLSEC_KEYINFO_FLAGS_X509DATA_DONT_VERIFY_CERTS) == 0) {
+            err = gnutls_x509_crt_list_verify(
+                    cert_list, (int)cert_list_cur_length, /* certs chain */
+                    ca_list, (int)ca_list_length, /* trusted cas */
+                    crl_list, (int)crl_list_length, /* crls */
+                    flags, /* flags */
+                    &verify);
+        } else {
+            err = GNUTLS_E_SUCCESS;
+        }
         if(err != GNUTLS_E_SUCCESS) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "gnutls_x509_crt_list_verify",
-                        XMLSEC_ERRORS_R_CRYPTO_FAILED,
-                        XMLSEC_GNUTLS_REPORT_ERROR(err));
+            xmlSecGnuTLSError("gnutls_x509_crt_list_verify", err, NULL);
             /* don't stop, continue! */
             continue;
-        } else if(verify != 0){
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "gnutls_x509_crt_list_verify",
-                        XMLSEC_ERRORS_R_CRYPTO_FAILED,
-                        "Verification failed: verify=%u", verify);
+        } else if(verify != 0) {
+            xmlSecOtherError2(XMLSEC_ERRORS_R_CERT_VERIFY_FAILED, NULL,
+                              "gnutls_x509_crt_list_verify: verification failed: status=%du",
+                              verify);
             /* don't stop, continue! */
             continue;
         }
@@ -385,11 +360,7 @@ xmlSecGnuTLSX509StoreVerify(xmlSecKeyDataStorePtr store,
            we have to do it ourselves */
         ret = xmlSecGnuTLSX509CheckTime(cert_list, cert_list_cur_length, verification_time);
         if(ret != 1) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "",
-                        XMLSEC_ERRORS_R_CRYPTO_FAILED,
-                        "Time verification failed");
+            xmlSecInternalError("xmlSecGnuTLSX509CheckTime", NULL);
             /* don't stop, continue! */
             continue;
         }
@@ -437,21 +408,15 @@ xmlSecGnuTLSX509StoreAdoptCert(xmlSecKeyDataStorePtr store, gnutls_x509_crt_t ce
     if((type & xmlSecKeyDataTypeTrusted) != 0) {
         ret = xmlSecPtrListAdd(&(ctx->certsTrusted), cert);
         if(ret < 0) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                        "xmlSecPtrListAdd(trusted)",
-                        XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                        XMLSEC_ERRORS_NO_MESSAGE);
+            xmlSecInternalError("xmlSecPtrListAdd(trusted)",
+                                xmlSecKeyDataStoreGetName(store));
             return(-1);
         }
     } else {
         ret = xmlSecPtrListAdd(&(ctx->certsUntrusted), cert);
         if(ret < 0) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                        "xmlSecPtrListAdd(untrusted)",
-                        XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                        XMLSEC_ERRORS_NO_MESSAGE);
+            xmlSecInternalError("xmlSecPtrListAdd(untrusted)",
+                                xmlSecKeyDataStoreGetName(store));
             return(-1);
         }
     }
@@ -474,21 +439,15 @@ xmlSecGnuTLSX509StoreInitialize(xmlSecKeyDataStorePtr store) {
 
     ret = xmlSecPtrListInitialize(&(ctx->certsTrusted), xmlSecGnuTLSX509CrtListId);
     if(ret < 0) {
-        xmlSecError(XMLSEC_ERRORS_HERE,
-                    xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                    "xmlSecPtrListInitialize(trusted)",
-                    XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                    XMLSEC_ERRORS_NO_MESSAGE);
+        xmlSecInternalError("xmlSecPtrListInitialize(trusted)",
+                            xmlSecKeyDataStoreGetName(store));
         return(-1);
     }
 
     ret = xmlSecPtrListInitialize(&(ctx->certsUntrusted), xmlSecGnuTLSX509CrtListId);
     if(ret < 0) {
-        xmlSecError(XMLSEC_ERRORS_HERE,
-                    xmlSecErrorsSafeString(xmlSecKeyDataStoreGetName(store)),
-                    "xmlSecPtrListInitialize(untrusted)",
-                    XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                    XMLSEC_ERRORS_NO_MESSAGE);
+        xmlSecInternalError("xmlSecPtrListInitialize(untrusted)",
+                            xmlSecKeyDataStoreGetName(store));
         return(-1);
     }
 
@@ -516,6 +475,7 @@ xmlSecGnuTLSX509StoreFinalize(xmlSecKeyDataStorePtr store) {
  *
  *****************************************************************************/
 #define XMLSEC_GNUTLS_DN_ATTRS_SIZE             1024
+
 static int
 xmlSecGnuTLSX509DnsEqual(const xmlChar * ll, const xmlChar * rr) {
     xmlSecGnuTLSDnAttr ll_attrs[XMLSEC_GNUTLS_DN_ATTRS_SIZE];
@@ -538,21 +498,13 @@ xmlSecGnuTLSX509DnsEqual(const xmlChar * ll, const xmlChar * rr) {
     /* parse */
     ret = xmlSecGnuTLSDnAttrsParse(ll, ll_attrs, XMLSEC_GNUTLS_DN_ATTRS_SIZE);
     if(ret < 0) {
-        xmlSecError(XMLSEC_ERRORS_HERE,
-                    NULL,
-                    "xmlSecGnuTLSDnAttrsParse(ll)",
-                    XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                    XMLSEC_ERRORS_NO_MESSAGE);
+        xmlSecInternalError("xmlSecGnuTLSDnAttrsParse(ll)", NULL);
         goto done;
     }
 
     ret = xmlSecGnuTLSDnAttrsParse(rr, rr_attrs, XMLSEC_GNUTLS_DN_ATTRS_SIZE);
     if(ret < 0) {
-        xmlSecError(XMLSEC_ERRORS_HERE,
-                    NULL,
-                    "xmlSecGnuTLSDnAttrsParse(rr)",
-                    XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                    XMLSEC_ERRORS_NO_MESSAGE);
+        xmlSecInternalError("xmlSecGnuTLSDnAttrsParse(rr)", NULL);
         goto done;
     }
 
@@ -564,11 +516,7 @@ xmlSecGnuTLSX509DnsEqual(const xmlChar * ll, const xmlChar * rr) {
     } else if(ret == 0) {
         res = 0;
     } else {
-        xmlSecError(XMLSEC_ERRORS_HERE,
-                    NULL,
-                    "xmlSecGnuTLSDnAttrsEqual",
-                    XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                    XMLSEC_ERRORS_NO_MESSAGE);
+        xmlSecInternalError("xmlSecGnuTLSDnAttrsEqual", NULL);
         goto done;
     }
 
@@ -593,11 +541,8 @@ xmlSecGnuTLSX509FindCert(xmlSecPtrListPtr certs,
     for(ii = 0; (ii < sz); ++ii) {
         gnutls_x509_crt_t cert = xmlSecPtrListGetItem(certs, ii);
         if(cert == NULL) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "xmlSecPtrListGetItem",
-                        XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                        "pos=%i", (int)ii);
+            xmlSecInternalError2("xmlSecPtrListGetItem", NULL,
+                                 "pos=%i", (int)ii);
             return(NULL);
         }
 
@@ -606,11 +551,8 @@ xmlSecGnuTLSX509FindCert(xmlSecPtrListPtr certs,
 
             tmp = xmlSecGnuTLSX509CertGetSubjectDN(cert);
             if(tmp == NULL) {
-                xmlSecError(XMLSEC_ERRORS_HERE,
-                            NULL,
-                            "xmlSecGnuTLSX509CertGetSubjectDN",
-                            XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                            "pos=%i", (int)ii);
+                xmlSecInternalError2("xmlSecGnuTLSX509CertGetSubjectDN", NULL,
+                                     "pos=%i", (int)ii);
                 return(NULL);
             }
 
@@ -625,21 +567,15 @@ xmlSecGnuTLSX509FindCert(xmlSecPtrListPtr certs,
 
             tmp1 = xmlSecGnuTLSX509CertGetIssuerDN(cert);
             if(tmp1 == NULL) {
-                xmlSecError(XMLSEC_ERRORS_HERE,
-                            NULL,
-                            "xmlSecGnuTLSX509CertGetIssuerDN",
-                            XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                            "pos=%i", (int)ii);
+                xmlSecInternalError2("xmlSecGnuTLSX509CertGetIssuerDN", NULL,
+                                     "pos=%i", (int)ii);
                 return(NULL);
             }
 
             tmp2 = xmlSecGnuTLSX509CertGetIssuerSerial(cert);
             if(tmp2 == NULL) {
-                xmlSecError(XMLSEC_ERRORS_HERE,
-                            NULL,
-                            "xmlSecGnuTLSX509CertGetIssuerSerial",
-                            XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                            "pos=%i", (int)ii);
+                xmlSecInternalError2("xmlSecGnuTLSX509CertGetIssuerSerial", NULL,
+                                     "pos=%i", (int)ii);
                 xmlFree(tmp1);
                 return(NULL);
             }
@@ -656,11 +592,8 @@ xmlSecGnuTLSX509FindCert(xmlSecPtrListPtr certs,
 
             tmp = xmlSecGnuTLSX509CertGetSKI(cert);
             if(tmp == NULL) {
-                xmlSecError(XMLSEC_ERRORS_HERE,
-                            NULL,
-                            "xmlSecGnuTLSX509CertGetSKI",
-                            XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                            "pos=%i", (int)ii);
+                xmlSecInternalError2("xmlSecGnuTLSX509CertGetSKI", NULL,
+                                     "pos=%i", (int)ii);
                 return(NULL);
             }
 
@@ -688,11 +621,7 @@ xmlSecGnuTLSX509FindSignedCert(xmlSecPtrListPtr certs, gnutls_x509_crt_t cert) {
     /* get subject */
     subject = xmlSecGnuTLSX509CertGetSubjectDN(cert);
     if(subject == NULL) {
-        xmlSecError(XMLSEC_ERRORS_HERE,
-                    NULL,
-                    "xmlSecGnuTLSX509CertGetSubjectDN",
-                    XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                    XMLSEC_ERRORS_NO_MESSAGE);
+        xmlSecInternalError("xmlSecGnuTLSX509CertGetSubjectDN", NULL);
         goto done;
     }
 
@@ -704,21 +633,15 @@ xmlSecGnuTLSX509FindSignedCert(xmlSecPtrListPtr certs, gnutls_x509_crt_t cert) {
 
         tmp = xmlSecPtrListGetItem(certs, ii);
         if(tmp == NULL) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "xmlSecPtrListGetItem",
-                        XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                        "pos=%i", (int)ii);
+            xmlSecInternalError2("xmlSecPtrListGetItem", NULL,
+                                 "pos=%i", (int)ii);
             goto done;
         }
 
         issuer = xmlSecGnuTLSX509CertGetIssuerDN(tmp);
         if(issuer == NULL) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "xmlSecGnuTLSX509CertGetIssuerDN",
-                        XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                        "pos=%i", (int)ii);
+            xmlSecInternalError2("xmlSecGnuTLSX509CertGetIssuerDN", NULL,
+                                 "pos=%i", (int)ii);
             goto done;
         }
 
@@ -749,11 +672,7 @@ xmlSecGnuTLSX509FindSignerCert(xmlSecPtrListPtr certs, gnutls_x509_crt_t cert) {
     /* get issuer */
     issuer = xmlSecGnuTLSX509CertGetIssuerDN(cert);
     if(issuer == NULL) {
-        xmlSecError(XMLSEC_ERRORS_HERE,
-                    NULL,
-                    "xmlSecGnuTLSX509CertGetIssuerDN",
-                    XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                    XMLSEC_ERRORS_NO_MESSAGE);
+        xmlSecInternalError("xmlSecGnuTLSX509CertGetIssuerDN", NULL);
         goto done;
     }
 
@@ -765,21 +684,15 @@ xmlSecGnuTLSX509FindSignerCert(xmlSecPtrListPtr certs, gnutls_x509_crt_t cert) {
 
         tmp = xmlSecPtrListGetItem(certs, ii);
         if(tmp == NULL) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "xmlSecPtrListGetItem",
-                        XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                        "pos=%i", (int)ii);
+            xmlSecInternalError2("xmlSecPtrListGetItem", NULL,
+                                 "pos=%i", (int)ii);
             goto done;
         }
 
         subject = xmlSecGnuTLSX509CertGetSubjectDN(tmp);
         if(subject == NULL) {
-            xmlSecError(XMLSEC_ERRORS_HERE,
-                        NULL,
-                        "xmlSecGnuTLSX509CertGetSubjectDN",
-                        XMLSEC_ERRORS_R_XMLSEC_FAILED,
-                        "pos=%i", (int)ii);
+            xmlSecInternalError2("xmlSecGnuTLSX509CertGetSubjectDN", NULL,
+                                 "pos=%i", (int)ii);
             goto done;
         }
 
