@@ -26,6 +26,7 @@
 #include <xmlsec/xmlsec.h>
 #include <xmlsec/nodeset.h>
 #include <xmlsec/errors.h>
+#include <xmlsec/private.h>
 
 #define xmlSecGetParent(node)           \
     (((node)->type != XML_NAMESPACE_DECL) ? \
@@ -500,6 +501,8 @@ xmlSecNodeSetDumpTextNodesWalkCallback(xmlSecNodeSetPtr nset, xmlNodePtr cur,
     xmlSecAssert2(cur != NULL, -1);
     xmlSecAssert2(data != NULL, -1);
 
+    UNREFERENCED_PARAMETER(parent);
+
     if(cur->type != XML_TEXT_NODE) {
         return(0);
     }
