@@ -25,10 +25,6 @@
 #include <errno.h>
 
 #include <libxml/tree.h>
-#include <openssl/evp.h>
-#include <openssl/x509.h>
-#include <openssl/x509_vfy.h>
-#include <openssl/x509v3.h>
 
 #include <xmlsec/xmlsec.h>
 #include <xmlsec/xmltree.h>
@@ -43,6 +39,11 @@
 #include <xmlsec/openssl/x509.h>
 #include "openssl_compat.h"
 
+#include <openssl/evp.h>
+#include <openssl/x509.h>
+#include <openssl/x509_vfy.h>
+#include <openssl/x509v3.h>
+
 /**************************************************************************
  *
  * Internal OpenSSL X509 store CTX
@@ -810,15 +811,22 @@ xmlSecOpenSSLX509FindCert(STACK_OF(X509) *certs, xmlChar *subjectName,
         for(i = 0; i < sk_X509_num(certs); ++i) {
             cert = sk_X509_value(certs, i);
             index = X509_get_ext_by_NID(cert, NID_subject_key_identifier, -1);
-            if((index >= 0)  && (ext = X509_get_ext(cert, index))) {
-                keyId = (ASN1_OCTET_STRING *)X509V3_EXT_d2i(ext);
-                if((keyId != NULL) && (keyId->length == len) &&
-                                    (memcmp(keyId->data, ski, len) == 0)) {
-                    ASN1_OCTET_STRING_free(keyId);
-                    return(cert);
-                }
-                ASN1_OCTET_STRING_free(keyId);
+            if(index < 0) {
+                continue;
             }
+            ext = X509_get_ext(cert, index);
+            if(ext == NULL) {
+                continue;
+            }
+            keyId = (ASN1_OCTET_STRING *)X509V3_EXT_d2i(ext);
+            if(keyId == NULL) {
+                continue;
+            }
+            if((keyId->length == len) && (memcmp(keyId->data, ski, len) == 0)) {
+                ASN1_OCTET_STRING_free(keyId);
+                return(cert);
+            }
+            ASN1_OCTET_STRING_free(keyId);
         }
     }
 
@@ -1028,9 +1036,9 @@ xmlSecOpenSSLX509NameStringRead(xmlSecByte **str, int *strLen,
         xmlSecInvalidSizeOtherError("buffer is too small", NULL);
         return(-1);
     }
-    (*strLen) -= (p - (*str));
+    (*strLen) -= (int)(p - (*str));
     (*str) = p;
-    return((ingoreTrailingSpaces) ? nonSpace - res + 1 : q - res);
+    return(int)((ingoreTrailingSpaces) ? nonSpace - res + 1 : q - res);
 }
 
 /*
@@ -1177,7 +1185,6 @@ xmlSecOpenSSLX509_NAME_ENTRY_cmp(const X509_NAME_ENTRY * const *a, const X509_NA
     return(OBJ_cmp(a_name, b_name));
 }
 
-
 #endif /* XMLSEC_NO_X509 */
 
 
