@@ -412,12 +412,16 @@ xmlSecTmplReferenceAddTransform(xmlNodePtr referenceNode, xmlSecTransformId tran
         tmp = xmlSecGetNextElementNode(referenceNode->children);
         if(tmp == NULL) {
             transformsNode = xmlSecAddChild(referenceNode, xmlSecNodeTransforms, xmlSecDSigNs);
+            if(transformsNode == NULL) {
+                xmlSecInternalError("xmlSecAddChild(xmlSecNodeTransforms)", NULL);
+                return(NULL);
+            }
         } else {
             transformsNode = xmlSecAddPrevSibling(tmp, xmlSecNodeTransforms, xmlSecDSigNs);
-        }
-        if(transformsNode == NULL) {
-            xmlSecInternalError("xmlSecAddChild or xmlSecAddPrevSibling(xmlSecNodeTransforms)", NULL);
-            return(NULL);
+            if(transformsNode == NULL) {
+                xmlSecInternalError("xmlSecAddPrevSibling(xmlSecNodeTransforms)", NULL);
+                return(NULL);
+            }
         }
     }
 
@@ -1458,7 +1462,11 @@ xmlSecTmplTransformAddHmacOutputLength(xmlNodePtr transformNode, xmlSecSize bits
         return(-1);
     }
 
+#ifdef WIN32
+    sprintf_s(buf, sizeof(buf), "%lu", (unsigned long)bitsLen);
+#else  /* WIN32 */
     sprintf(buf, "%lu", (unsigned long)bitsLen);
+#endif /* WIN32 */
     xmlNodeSetContent(cur, BAD_CAST buf);
     return(0);
 }
